summaryrefslogtreecommitdiffstats
path: root/tdecore/kglobalaccel.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kglobalaccel.h')
-rw-r--r--tdecore/kglobalaccel.h70
1 files changed, 35 insertions, 35 deletions
diff --git a/tdecore/kglobalaccel.h b/tdecore/kglobalaccel.h
index 7fb44a021..a8ed8a955 100644
--- a/tdecore/kglobalaccel.h
+++ b/tdecore/kglobalaccel.h
@@ -21,49 +21,49 @@
#define _KGLOBALACCEL_H_
#include <tqobject.h>
-#include <kshortcut.h>
+#include <tdeshortcut.h>
class TQPopupMenu;
class TQWidget;
-class KAccelAction;
-class KAccelActions;
-class KConfigBase;
+class TDEAccelAction;
+class TDEAccelActions;
+class TDEConfigBase;
-class KGlobalAccelPrivate;
+class TDEGlobalAccelPrivate;
/**
* KGlobalAccel allows you to have global accelerators that are independent of
* the focused window. Unlike KAccel it does not matter which window is
* currently active.
*
-* @see KAccel
-* @see KAccelShortcutList
+* @see TDEAccel
+* @see TDEAccelShortcutList
* @see KKeyChooser
* @see KKeyDialog
* @short Configurable global shortcut support
*/
-class TDECORE_EXPORT KGlobalAccel : public TQObject
+class TDECORE_EXPORT TDEGlobalAccel : public TQObject
{
Q_OBJECT
public:
/**
* Creates a new KGlobalAccel object with the given pParent and
* psName.
* @param pParent the parent of the QObject
* @param psName the name of the QObject
*/
- KGlobalAccel( TQObject* pParent, const char* psName = 0 );
- virtual ~KGlobalAccel();
+ TDEGlobalAccel( TQObject* pParent, const char* psName = 0 );
+ virtual ~TDEGlobalAccel();
/**
* Checks whether the accelerators are enabled.
* @return true if the KGlobalAccel is enabled
*/
bool isEnabled();
/**
* Enables or disables the KGlobalAccel
* @param bEnabled true if the KGlobalAccel should be enabled, false if it
* should be disabled.
*/
void setEnabled( bool bEnabled );
@@ -90,8 +90,8 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* @param bConfigurable Allow the user to change this shortcut if set to 'true'.
* @param bEnabled The action will be activated by the shortcut if set to 'true'.
*/
- KAccelAction* insert( const TQString& sAction, const TQString& sLabel, const TQString& sWhatsThis,
- const KShortcut& cutDef3, const KShortcut& cutDef4,
+ TDEAccelAction* insert( const TQString& sAction, const TQString& sLabel, const TQString& sWhatsThis,
+ const TDEShortcut& cutDef3, const TDEShortcut& cutDef4,
const TQObject* pObjSlot, const char* psMethodSlot,
bool bConfigurable = true, bool bEnabled = true );
@@ -108,9 +108,9 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* displayed when the user configures shortcuts.
* @param sName of the of the action to insert
* @param sLabel a user-readable (i18n!) name for the action
- * @return the KAccelAction of the action
+ * @return the TDEAccelAction of the action
*/
- KAccelAction* insert( const TQString& sName, const TQString& sLabel );
+ TDEAccelAction* insert( const TQString& sName, const TQString& sLabel );
/**
* Updates the connections of the accelerations after changing them.
@@ -123,14 +123,14 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* @param sAction the name of the action
* @return the shortcut. If the action does not exist a null shortcut will be returned.
*/
- const KShortcut& shortcut( const TQString& sAction ) const;
+ const TDEShortcut& shortcut( const TQString& sAction ) const;
/**
* Set the shortcut to be associated with the action named by @p sAction.
* @param sAction the name of the action
* @param shortcut the shortcut for the action
* @return true if successful, false otherwise
*/
- bool setShortcut( const TQString& sAction, const KShortcut &shortcut );
+ bool setShortcut( const TQString& sAction, const TDEShortcut &shortcut );
/**
* Set the slot to be called when the shortcut of the action named
* by @p sAction is pressed.
@@ -157,26 +157,26 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
/**
* Returns the configuration group that is used to save the accelerators.
* @return the configuration group
- * @see KConfig
+ * @see TDEConfig
*/
const TQString& configGroup() const;
/**
* Sets the configuration group that is used to save the accelerators.
* @param cg the configuration group
- * @see KConfig
+ * @see TDEConfig
*/
void setConfigGroup( const TQString &cg );
/**
* Read all shortcuts from @p pConfig, or (if @p pConfig
* is zero) from the application's configuration file
- * KGlobal::config().
+ * TDEGlobal::config().
* @param pConfig the configuration file to read from, or 0 for the application
* configuration file
* @return true if successful, false otherwise
*/
- bool readSettings( KConfigBase* pConfig = 0 );
+ bool readSettings( TDEConfigBase* pConfig = 0 );
/**
* Write the current shortcuts to @p pConfig,
@@ -187,7 +187,7 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* @return true if successful, false otherwise
* @since 3.1
*/
- bool writeSettings( KConfigBase* pConfig = 0 ) const;
+ bool writeSettings( TDEConfigBase* pConfig = 0 ) const;
// BCI: merge these two writeSettings methods in KDE 4.0
/**
* Write the current shortcuts to @p pConfig,
@@ -199,11 +199,11 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* @param bGlobal if true write the configuration to the kde global settings
* @return true if successful, false otherwise
*/
- bool writeSettings( KConfigBase* pConfig, bool bGlobal ) const;
+ bool writeSettings( TDEConfigBase* pConfig, bool bGlobal ) const;
/**
* @internal -- this a wrapper function to
- * KAccelActions::useFourModifierKeys().
+ * TDEAccelActions::useFourModifierKeys().
*/
static bool useFourModifierKeys();
@@ -219,21 +219,21 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
/**
* @internal
*/
// like setEnabled(), but doesn't ungrab (see in KGlobalAccelPrivate)
void suspend( bool s );
private:
- KAccelActions& actions();
- const KAccelActions& actions() const;
+ TDEAccelActions& actions();
+ const TDEAccelActions& actions() const;
- friend class KGlobalAccelPrivate;
- friend class KAccelShortcutList;
+ friend class TDEGlobalAccelPrivate;
+ friend class TDEAccelShortcutList;
protected:
/** \internal */
virtual void virtual_hook( int id, void* data );
private:
- class KGlobalAccelPrivate* d;
+ class TDEGlobalAccelPrivate* d;
};
#endif // _KGLOBALACCEL_H_
@@ -21,49 +21,49 @@
/**
-* KGlobalAccel allows you to have global accelerators that are independent of
-* the focused window. Unlike KAccel it does not matter which window is
+* TDEGlobalAccel allows you to have global accelerators that are independent of
+* the focused window. Unlike TDEAccel it does not matter which window is
* currently active.
*
@@ -21,49 +21,49 @@
public:
/**
- * Creates a new KGlobalAccel object with the given pParent and
+ * Creates a new TDEGlobalAccel object with the given pParent and
* psName.
* @param pParent the parent of the QObject
@@ -21,49 +21,49 @@
/**
* Checks whether the accelerators are enabled.
- * @return true if the KGlobalAccel is enabled
+ * @return true if the TDEGlobalAccel is enabled
*/
bool isEnabled();
@@ -21,49 +21,49 @@
bool isEnabled();
/**
- * Enables or disables the KGlobalAccel
- * @param bEnabled true if the KGlobalAccel should be enabled, false if it
+ * Enables or disables the TDEGlobalAccel
+ * @param bEnabled true if the TDEGlobalAccel should be enabled, false if it
* should be disabled.
*/
@@ -219,21 +219,21 @@ class TDECORE_EXPORT KGlobalAccel : public TQObject
* @internal
*/
- // like setEnabled(), but doesn't ungrab (see in KGlobalAccelPrivate)
+ // like setEnabled(), but doesn't ungrab (see in TDEGlobalAccelPrivate)
void suspend( bool s );
private: